import { select, range, scaleOrdinal } from 'd3';

const svg = d3.select("svg");
const height = +svg.attr("height");
const width = +svg.attr("width");

const colorScale = scaleOrdinal()
	.domain(['Apple', 'Lemon'])
	.range(["red", "yellow"]);

const radiusScale = scaleOrdinal()
	.domain(['Apple', 'Lemon'])
	.range([50, 30])

const render = (selection, props) => {
  const { fruits } = props;
  const dataSelection = selection.selectAll("circle").data(fruits);  
  
  //Enter Selection
  dataSelection
    .enter().append("circle")
      .attr("cx", (d,i)=> i * 120 + 100)
      .attr("cy", height / 2)  
  	.merge(dataSelection)
      .attr("r", (d,i)=> radiusScale(d.type))
      .attr("fill", (d,i)=> colorScale(d.type)) 		
  		.attr("test", (d,i) => console.log('Enter Selection', d))
  
  //Update Selection
  dataSelection
  	.attr("r", (d,i)=> radiusScale(d.type))
    .attr("fill", (d,i)=> colorScale(d.type))
  	.attr("test", (d,i) => console.log('Update Selection', d));
  
  //Exit Selection
  dataSelection
		.exit()
  	.attr("test", (d,i)=>console.log("Exit Selection",d))
    .remove();
}

const makeFruit = type => ({type, id: Math.random()}); //create a fruit

const fruits = range(5)
	.map(() => makeFruit("Apple"));

render (svg, {fruits});	


//Replacing an apple with lemon
setTimeout(()=>{
	fruits[2].type = "Lemon";
	render (svg, {fruits});  
}, 4000)

//Eat apple
setTimeout(()=>{
	fruits.pop();
	render (svg, {fruits});  
}, 3000)
